==> haskell-vector-algorithms-0.9.1.0-115.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-algorithms.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-algorithms
version:              0.9.1.0
visibility:           public
id:                   vector-algorithms-0.9.1.0-nPezpE6T5gHv4BTs4clf9
key:                  vector-algorithms-0.9.1.0-nPezpE6T5gHv4BTs4clf9
license:              BSD-3-Clause
copyright:
    (c) 2008,2009,2010,2011,2012,2013,2014,2015 Dan Doel
    (c) 2015 Tim Baumann

maintainer:
    Dan Doel <dan.doel@gmail.com>
    Erik de Castro Lopo <erikd@mega-nerd.com>

author:               Dan Doel
homepage:             https://github.com/erikd/vector-algorithms/
synopsis:             Efficient algorithms for vector arrays
description:
    Efficient algorithms for sorting vector arrays. At some stage
    other vector algorithms may be added.

category:             Data
abi:                  647c6e604b2558e6429aae6fe8a9b41b
exposed:              True
exposed-modules:
    Data.Vector.Algorithms Data.Vector.Algorithms.AmericanFlag
    Data.Vector.Algorithms.Heap Data.Vector.Algorithms.Insertion
    Data.Vector.Algorithms.Intro Data.Vector.Algorithms.Merge
    Data.Vector.Algorithms.Optimal Data.Vector.Algorithms.Radix
    Data.Vector.Algorithms.Search Data.Vector.Algorithms.Tim

hidden-modules:       Data.Vector.Algorithms.Common
import-dirs:          /usr/lib/ghc-9.6.6/site-local/vector-algorithms-0.9.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/vector-algorithms-0.9.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/vector-algorithms-0.9.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-algorithms
hs-libraries:         HSvector-algorithms-0.9.1.0-nPezpE6T5gHv4BTs4clf9
include-dirs:
    /usr/lib/ghc-9.6.6/site-local/vector-algorithms-0.9.1.0/include

depends:
    base-4.18.2.1 bitvec-1.1.5.0-2hC1G34fm4D80nTSaXKdsx
    bytestring-0.11.5.3 primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:
    /usr/share/doc/haskell-vector-algorithms/html/vector-algorithms.haddock

haddock-html:         /usr/share/doc/haskell-vector-algorithms/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-algorithms-0.9.1.0-116-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-algorithms.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-algorithms
version:              0.9.1.0
visibility:           public
id:                   vector-algorithms-0.9.1.0-GdPL2rq4cry7HNPKxZ4cz0
key:                  vector-algorithms-0.9.1.0-GdPL2rq4cry7HNPKxZ4cz0
license:              BSD-3-Clause
copyright:
    (c) 2008,2009,2010,2011,2012,2013,2014,2015 Dan Doel
    (c) 2015 Tim Baumann

maintainer:
    Dan Doel <dan.doel@gmail.com>
    Erik de Castro Lopo <erikd@mega-nerd.com>

author:               Dan Doel
homepage:             https://github.com/erikd/vector-algorithms/
synopsis:             Efficient algorithms for vector arrays
description:
    Efficient algorithms for sorting vector arrays. At some stage
    other vector algorithms may be added.

category:             Data
abi:                  8a7c1ad6f030f7638880644d4debe83e
exposed:              True
exposed-modules:
    Data.Vector.Algorithms Data.Vector.Algorithms.AmericanFlag
    Data.Vector.Algorithms.Heap Data.Vector.Algorithms.Insertion
    Data.Vector.Algorithms.Intro Data.Vector.Algorithms.Merge
    Data.Vector.Algorithms.Optimal Data.Vector.Algorithms.Radix
    Data.Vector.Algorithms.Search Data.Vector.Algorithms.Tim

hidden-modules:       Data.Vector.Algorithms.Common
import-dirs:          /usr/lib/ghc-9.6.6/site-local/vector-algorithms-0.9.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/vector-algorithms-0.9.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/vector-algorithms-0.9.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-algorithms
hs-libraries:         HSvector-algorithms-0.9.1.0-GdPL2rq4cry7HNPKxZ4cz0
include-dirs:
    /usr/lib/ghc-9.6.6/site-local/vector-algorithms-0.9.1.0/include

depends:
    base-4.18.2.1 bitvec-1.1.5.0-I9FXtqrXcKw7jfMo2SGACo
    bytestring-0.11.5.3 primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:
    /usr/share/doc/haskell-vector-algorithms/html/vector-algorithms.haddock

haddock-html:         /usr/share/doc/haskell-vector-algorithms/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
